using UnityEngine;
using UnityEngine.UI;
using UnityEngine.XR;
using System;
using System.Collections;
using System.Collections.Generic;
using SimpleJSON;
using System.Linq;
using System.IO;
using MeshVR;

// VAMStory - VAMSFovController v1.0
//
// Controls the FOV of the main camera

namespace VAMStory
{
    public class VAMSFovController : MVRScript
    {	
		// Static string
		public static string PLUGIN_PATH;
		public static string EXCEPTION_PREFIX = "VAMSDistance - Exception caught: ";

		// JSONStorables
		public JSONStorableFloat FOVValue;
		
		// Game Objects and components
		
		// Misc
		private float _originalFOV = 0f;
			
		public override void Init()
        {			 
            try
            {
	            PLUGIN_PATH = Utils.GetPluginPath(this);
	            
	            _originalFOV = SuperController.singleton.monitorCameraFOV;
                FOVValue = new JSONStorableFloat("FOV Value", _originalFOV, FOVValueCallback, 1f, 100f){ isStorable = false };
				CreateSlider(FOVValue);

				RegisterFloat(FOVValue);
				
				Utils.CreateStaticDescriptionText(this,"VAMM2Title","<color=#000><size=35><b>VAMSFovController</b></size></color>",true,40,TextAnchor.MiddleRight);
				Utils.CreateStaticDescriptionText(this,"Right UI Main Title","<color=#000><size=28>Allows you to control the FOV of the main camera. Can be used to enforce a FOV for a desktop scene, or animate FOV for a cinematic scene.</size></color>",true,135,TextAnchor.MiddleRight);

            }
            catch(Exception e)
            {
                SuperController.LogError("FovController - Exception caught: " + e);
            }
		}
		
		void Start()
        {
			try
            {

			}
            catch(Exception e)
            {
                SuperController.LogError("FovController - Exception caught: " + e);
            }
        }
		
		void Update() {

		}
			
		// **************************
		// Callbacks & similar
		// **************************
		private void FOVValueCallback(float FOVValue)
		{
			SuperController.singleton.monitorCameraFOV = FOVValue;
		}

		// **************************
		// Local Tools
		// **************************
		private void logDebug( string debugText ) {
			SuperController.LogMessage( debugText );
		}
				
		// **************************
		// Time to cleanup !
		// **************************
		void OnDestroy()
		{
			SuperController.singleton.monitorCameraFOV = _originalFOV;
		}

	}
}